import requests
from . import auth

class SoftwareSuggestion:

    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = 'https://apix.cisco.com/software/suggestion/v2/suggestions'
        self.headers = {
            'Authorization': f'Bearer {self.access_token}'
        }

    def get_suggested_releases_and_images_by_pid(self, pids, page_index=1):
        params = {
            'pageIndex': page_index,
        }
        url = f"{self.base_url}/software/productIds/{','.join(pids)}?pageIndex={page_index}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_suggested_releases_by_pid(self, pids, page_index=1):
        params = {
            'pageIndex': page_index,
        }
        url = f"{self.base_url}/releases/productIds/{','.join(pids)}?pageIndex={page_index}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_compatible_and_suggested_software_release_by_pid(self, pid, current_image=None, current_release=None, page_index=1, supported_features=None, supported_hardware=None):
        params = {
            'pageIndex': page_index,
            'currentImage': current_image,
            'currentRelease': current_release
        }
        if supported_features:
            params['supportedFeatures'] = ','.join(supported_features)
        if supported_hardware:
            params['supportedHardware'] = ','.join(supported_hardware)
        # remove all None values from params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/compatible/productId/{pid}?pageIndex={page_index}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_suggested_releases_and_images_by_mdf_ids(self, mdf_ids, page_index=1):
        params = {
            'pageIndex': page_index,
        }
        url = f"{self.base_url}/software/mdfIds/{','.join(mdf_ids)}?pageIndex={page_index}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_suggested_releases_by_mdf_ids(self, mdf_ids, page_index=1):
        params = {
            'pageIndex': page_index,
        }
        url = f"{self.base_url}/releases/mdfIds/{','.join(mdf_ids)}?pageIndex={page_index}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_compatible_and_suggested_software_releases_by_mdf_id(self, mdf_is, current_image=None, current_release=None, page_index=1, supported_features=None, supported_hardware=None):
        params = {
            'pageIndex': page_index,
            'currentImage': current_image,
            'currentRelease': current_release
        }
        if supported_features:
            params['supportedFeatures'] = ','.join(supported_features)
        if supported_hardware:
            params['supportedHardware'] = ','.join(supported_hardware)
        # remove all None values from params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/compatible/mdfId/{mdf_is}?pageIndex={page_index}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()


import requests

def generate_access_token(client_id, client_secret):
    url = 'https://id.cisco.com/oauth2/default/v1/token'
    headers = {
        'Content-Type': 'application/x-www-form-urlencoded'
    }
    data = {
        'client_id': client_id,
        'client_secret': client_secret,
        'grant_type': 'client_credentials'
    }

    response = requests.post(url, headers=headers, data=data)


    try:
        return response.json()['access_token']
    except:
        raise Exception(response.json()['errorSummary'])




import requests
import json
from . import auth

class AutomatedSoftwareDistribution:

    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = 'https://apix.cisco.com/software/v4.0'
        self.headers = {
            'Authorization': f'Bearer {self.access_token}',
            'Content-Type': 'application/json'
        }


    def get_software_release_by_pid_and_release(self, pid, current_release_version, output_release_version, page_index=1, per_page=25):
        data = {
            'pid': pid,
            'currentReleaseVersion': current_release_version,
            'OutputReleaseVersion': output_release_version,
            'pageIndex': page_index,
            'perPage': per_page

        }
        url = f"{self.base_url}/metadata/pidrelease"
        response = requests.post(url, headers=self.headers, data=json.dumps(data))
        try:
            return response.json()
        except:
            raise Exception(f'{response.status_code} - {response.text}')


import requests
from . import auth

class ServiceOrderReturn:

    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = 'https://apix.cisco.com/return/v1.0/returns'
        self.headers = {
            'Authorization': f'Bearer {self.access_token}'
        }

    def get_by_rma_number(self, rma_number):
        url = f'{self.base_url}/rma_numbers/{rma_number}'
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_user_id(self, user_id, from_date=None, to_date=None, status=None, sort_by='orderdate'):
        params = {
            'fromDate': from_date,
            'toDate': to_date,
            'status': status,
            'sortBy': sort_by
        }
        # Remove None values
        params = {k: v for k, v in params.items() if v is not None}
        url = f'{self.base_url}/users/{user_id}'
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()


import requests
from . import auth

class Bug:

    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = 'https://apix.cisco.com/bug/v2.0/bugs'
        self.headers = {
            'Authorization': f'Bearer {self.access_token}'
        }

    def get_by_ids(self, bug_ids):
        url = f"{self.base_url}/bug_ids/{','.join(bug_ids)}"
        print(url)
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_product_id(self, product_id, page_index=1, status=None, modified_date=None, severity=None, sort_by=None):
        params = {
            'page_index': page_index,
            'status': status,
            'modified_date': modified_date,
            'severity': severity,
            'sort_by': sort_by
        }
        # Remove any None values from the params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/products/product_id/{product_id}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_by_pid_and_software_release(self, pid, software_release, page_index=1, status=None, modified_date=None, severity=None, sort_by=None):
        params = {
            'page_index': page_index,
            'status': status,
            'modified_date': modified_date,
            'severity': severity,
            'sort_by': sort_by
        }
        # Remove any None values from the params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/products/product_id/{pid}/software_releases/{software_release}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_by_keywords(self, keywords, page_index=1, status=None, modified_date=None, severity=None, sort_by=None):
        params = {
            'page_index': page_index,
            'status': status,
            'modified_date': modified_date,
            'severity': severity,
            'sort_by': sort_by
        }
        # Remove any None values from the params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/keyword/{' '.join(keywords)}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_by_product_series_and_affected_software_release(self, product_series, affected_releases, page_index=1, status=None, modified_date=None, severity=None, sort_by=None):
        params = {
            'page_index': page_index,
            'status': status,
            'modified_date': modified_date,
            'severity': severity,
            'sort_by': sort_by
        }
        # Remove any None values from the params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/product_series/{product_series}/affected_releases/{affected_releases}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_by_product_series_and_fixed_in_software_release(self, product_series, fixed_in_releases, page_index=1, status=None, modified_date=None, severity=None, sort_by=None):
        params = {
            'page_index': page_index,
            'status': status,
            'modified_date': modified_date,
            'severity': severity,
            'sort_by': sort_by
        }
        # Remove any None values from the params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/product_series/{product_series}/fixed_in_releases/{fixed_in_releases}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_by_product_name_and_affected_software_release(self, product_name, affected_releases, page_index=1, status=None, modified_date=None, severity=None, sort_by=None):
        params = {
            'page_index': page_index,
            'status': status,
            'modified_date': modified_date,
            'severity': severity,
            'sort_by': sort_by
        }
        # Remove any None values from the params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/product_name/{product_name}/affected_releases/{affected_releases}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_by_product_name_and_fixed_in_software_release(self, product_name, fixed_in_releases, page_index=1, status=None, modified_date=None, severity=None, sort_by=None):
        params = {
            'page_index': page_index,
            'status': status,
            'modified_date': modified_date,
            'severity': severity,
            'sort_by': sort_by
        }
        # Remove any None values from the params
        params = {k: v for k, v in params.items() if v is not None}
        url = f"{self.base_url}/product_name/{product_name}/fixed_in_releases/{fixed_in_releases}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()


import requests
from . import auth

class SerialNumberInformation:

    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = 'https://apix.cisco.com/sn2info/v2'
        self.headers = {
            'Authorization': f'Bearer {self.access_token}'
        }

    def get_coverage_status_by_serial_numbers(self, serial_numbers):
        url = f"{self.base_url}/coverage/status/serial_numbers/{','.join(serial_numbers)}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_coverage_summary_by_serial_numbers(self, serial_numbers, page_index=1):
        params = {
            'page_index': page_index
        }
        url = f"{self.base_url}/coverage/summary/serial_numbers/{','.join(serial_numbers)}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_coverage_status_by_instance_numbers(self, instance_numbers, page_index=1):
        params = {
            'page_index': page_index
        }
        url = f"{self.base_url}/coverage/summary/instance_numbers/{','.join(instance_numbers)}"
        response = requests.get(url, headers=self.headers, params=params)
        return response.json()

    def get_orderable_product_ids_by_serial_numbers(self, serial_numbers):
        url = f"{self.base_url}/identifiers/orderable/serial_numbers/{','.join(serial_numbers)}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_owner_coverage_status_by_serial_numbers(self, serial_numbers):
        url = f"{self.base_url}/coverage/owner_status/serial_numbers/{','.join(serial_numbers)}"
        response = requests.get(url, headers=self.headers)
        return response.json()


import requests
from . import auth

class ProductInformation:

    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = "https://apix.cisco.com/product/v1/information"
        self.headers = {
            'Authorization': f'Bearer {self.access_token}'
        }

    def get_by_serial_numbers(self, serial_numbers, pageIndex=1):
        url = f"{self.base_url}/serial_numbers/{','.join(serial_numbers)}?responseencoding=json&page_index={pageIndex}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_product_ids(self, product_ids, pageIndex=1):
        url = f"{self.base_url}/product_ids/{','.join(product_ids)}?responseencoding=json&page_index={pageIndex}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_mdf_by_ids(self, product_ids, pageIndex=1):
        url = f"{self.base_url}/mdf/product_ids_mdf/{','.join(product_ids)}?responseencoding=json&page_index={pageIndex}"
        response = requests.get(url, headers=self.headers)
        return response.json()


from .automated_software_distribution import *
from .bug import *
from .case import *
from .eox import *
from .product_information import *
from .serial_number import *
from .service_order_return import *
from .software_suggestion import *


import requests
from . import auth

class EoX:
    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = "https://apix.cisco.com/supporttools/eox/rest/5"
        self.headers = {
            'Authorization': f'Bearer {self.access_token}'
        }

    def get_by_dates(self, start_date, end_date, page_index=1):
        url = f"{self.base_url}/EOXByDates/{page_index}/{start_date}/{end_date}?responseencoding=json"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_product_ids(self, product_ids, page_index=1):
        url = f"{self.base_url}/EOXByProductID/{page_index}/{','.join(product_ids)}?responseencoding=json"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_serial_numbers(self, serial_numbers, page_index=1):
        url = f"{self.base_url}/EOXBySerialNumber/{page_index}/{','.join(serial_numbers)}?responseencoding=json"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_software_release_strings(self, softwares, page_index=1):
        sw = []
        for i, software in enumerate(softwares):
            sw.append(f"input{i+1}={software}")
        url = f"{self.base_url}/EOXBySWReleaseString/{page_index}?{'&'.join(sw)}&responseencoding=json"
        response = requests.get(url, headers=self.headers)
        return response.json()


import requests
from . import auth

class Case:

    def __init__(self, client_id, client_secret):
        self.access_token = auth.generate_access_token(client_id, client_secret)
        self.base_url = 'https://apix.cisco.com/case/v3/cases'
        self.headers = {
            'Authorization': f'Bearer {self.access_token}'
        }

    def get_summary_by_ids(self, case_ids, sort_by='STATUS'):
        url = f"{self.base_url}/case_ids/{','.join(case_ids)}?sort_by={sort_by}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_details_by_id(self, case_id):
        url = f"{self.base_url}/details/case_id/{case_id}"
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_contract_ids(self, contract_ids, date_created_from=None, date_created_to=None, status_flag=None, sort_by='UPDATED_DATE', page_index=1):
        params = {
            'date_created_from': date_created_from,
            'date_created_to': date_created_to,
            'status_flag': status_flag,
            'sort_by': sort_by,
            'page_index': page_index
        }
        # remove None values
        params = {k: v for k, v in params.items() if v is not None}

        url = f"{self.base_url}/contracts/contract_ids/{','.join(contract_ids)}?{requests.compat.urlencode(params)}"
        print(url)
        response = requests.get(url, headers=self.headers)
        return response.json()

    def get_by_user_ids(self, user_ids, date_created_from=None, date_created_to=None, status_flag=None, sort_by='UPDATED_DATE', page_index=1):
        params = {
            'date_created_from': date_created_from,
            'date_created_to': date_created_to,
            'status_flag': status_flag,
            'sort_by': sort_by,
            'page_index': page_index
        }
        # remove None values
        params = {k: v for k, v in params.items() if v is not None}

        url = f"{self.base_url}/users/user_ids/{','.join(user_ids)}?{requests.compat.urlencode(params)}"
        response = requests.get(url, headers=self.headers)
        return response.json()